@@ -1,5 +1,5 @@
 import sys
-from typing import Any, Iterable, Mapping
+from typing import Any, Iterable, Mapping, Sequence
 
 from pychoir.core import Matchable, Matcher
 
@@ -17,10 +17,10 @@ class IsEmpty(Matcher):
     """A Matcher checking that the `len()` of the compared value is 0.
 
     Usage:
-      >> from pychoir import All, IsEmpty, Not
-      >> ('', [], {}, set(), tuple()) == All(IsEmpty())
+      >>> from pychoir import All, IsEmpty, Not
+      >>> ('', [], {}, set(), tuple()) == All(IsEmpty())
       True
-      >> {'not': 'empty'} == Not(IsEmpty())
+      >>> {'not': 'empty'} == Not(IsEmpty())
       True
     """
 
@@ -202,6 +202,37 @@ class DictContainsAllOf(Matcher):
         return repr(self.expected)
 
 
+class InAnyOrder(Matcher):
+    """A Matcher checking that a Sequence contains *exactly* the passed items, in any order.
+
+    :param value: A Sequence containing the expected items, in any order.
+
+    Usage:
+      >>> from pychoir import InAnyOrder
+      >>> [1, 2, 3, 3] == InAnyOrder([3, 2, 3, 1])
+      True
+      >>> [1, 2] == InAnyOrder([3, 2, 1])
+      False
+      >>> [{'a': 1}, {'b': 2}] == InAnyOrder([{'b': 2}, {'a': 1}])
+      True
+    """
+    def __init__(self, values: Sequence[Any]):
+        super().__init__()
+        self.expected_values = values
+
+    def _matches(self, other: Iterable[Any]) -> bool:
+        values_left = [value for value in self.expected_values]
+        for value in other:
+            try:
+                values_left.remove(value)
+            except ValueError:
+                return False
+        return not values_left
+
+    def _description(self) -> str:
+        return repr(self.expected_values)
+
+
 class _NotPresent:
     def __str__(self) -> str:
         return 'NotPresent'
